aboutsummaryrefslogtreecommitdiffstats
path: root/includes/MovePage.php
diff options
context:
space:
mode:
authorRoan Kattouw <roan.kattouw@gmail.com>2020-06-16 22:23:50 -0700
committerRoan Kattouw <roan.kattouw@gmail.com>2020-06-16 22:27:28 -0700
commitc8b9d849fc2ef302ec2adf5ec3bdb647d176c2ab (patch)
tree3dc0c052019815f539a9c0554c9581bff92555f1 /includes/MovePage.php
parent38accc1457f686abbf7f74cf06787037f3668981 (diff)
downloadmediawikicore-c8b9d849fc2ef302ec2adf5ec3bdb647d176c2ab.tar.gz
mediawikicore-c8b9d849fc2ef302ec2adf5ec3bdb647d176c2ab.zip
Add PageMoveCompleting hook, to replace TitleMoveCompleting
We intially thought we wouldn't need this and would only need PageMoveComplete, but it turns out Flow does need it. Bug: T250023 Bug: T255608 Change-Id: I8e7308541d2fe6d02b9dad63e1c86c89f6e7cf53
Diffstat (limited to 'includes/MovePage.php')
-rw-r--r--includes/MovePage.php7
1 files changed, 6 insertions, 1 deletions
diff --git a/includes/MovePage.php b/includes/MovePage.php
index 9a6e2aad0f42..6b56815011d8 100644
--- a/includes/MovePage.php
+++ b/includes/MovePage.php
@@ -694,7 +694,12 @@ class MovePage {
}
}
- // Deprecated since 1.35, use PageMoveComplete
+ $this->hookRunner->onPageMoveCompleting(
+ $this->oldTitle, $this->newTitle,
+ $user, $pageid, $redirid, $reason, $nullRevision
+ );
+
+ // Deprecated since 1.35, use PageMoveCompleting
// TODO hard deprecate
$nullRevisionObj = new Revision( $nullRevision );
$this->hookRunner->onTitleMoveCompleting(